pub struct CallbackTokenVerificationRequest {
pub email: Option<String>,
pub mobile: Option<String>,
pub token: String,
}Expand description
CallbackTokenVerificationRequest : Takes a user and a token, verifies the token belongs to the user and validates the alias that the token was sent from.
Fields
email: Option<String>mobile: Option<String>token: StringImplementations
Sourceimpl CallbackTokenVerificationRequest
impl CallbackTokenVerificationRequest
Sourcepub fn new(token: String) -> CallbackTokenVerificationRequest
pub fn new(token: String) -> CallbackTokenVerificationRequest
Takes a user and a token, verifies the token belongs to the user and validates the alias that the token was sent from.